==> jc-1.4.0.tar.gz: soot/jimple/NaiveSideEffectTester.h <==
// public class soot.jimple.NaiveSideEffectTester

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7b79e7dcca142ae9 soot_jimple_NaiveSideEffectTester

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_NaiveSideEffectTester_H_
#define _JC_soot_jimple_NaiveSideEffectTester_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_NaiveSideEffectTester$sub_refs	_jc_soot_jimple_NaiveSideEffectTester$sub_refs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs	_jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$refs	_jc_soot_jimple_NaiveSideEffectTester$refs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$nonrefs	_jc_soot_jimple_NaiveSideEffectTester$nonrefs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$object	_jc_soot_jimple_NaiveSideEffectTester$object;

typedef const struct _jc_soot_jimple_NaiveSideEffectTester$vmethods	_jc_soot_jimple_NaiveSideEffectTester$vmethods;
typedef const struct _jc_soot_jimple_NaiveSideEffectTester$vtable	_jc_soot_jimple_NaiveSideEffectTester$vtable;
typedef const struct _jc_soot_jimple_NaiveSideEffectTester$vtype	_jc_soot_jimple_NaiveSideEffectTester$vtype;

// Constructors
extern void _jc_soot_jimple_NaiveSideEffectTester$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *);

// Virtual methods
extern void _jc_soot_jimple_NaiveSideEffectTester$method$newMethod$b27d7d51d7418014(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_soot_SootMethod$object *);
extern jboolean _jc_soot_jimple_NaiveSideEffectTester$method$unitCanReadFrom$0db80b916700aa7c(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_NaiveSideEffectTester$method$unitCanWriteTo$e50298a7ad8b028b(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_NaiveSideEffectTester$method_info$newMethod$b27d7d51d7418014;
extern _jc_method _jc_soot_jimple_NaiveSideEffectTester$method_info$unitCanReadFrom$0db80b916700aa7c;
extern _jc_method _jc_soot_jimple_NaiveSideEffectTester$method_info$unitCanWriteTo$e50298a7ad8b028b;

// Virtual methods structure
struct _jc_soot_jimple_NaiveSideEffectTester$vmethods {
	void	(*newMethod$b27d7d51d7418014)(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_soot_SootMethod$object *);
	jboolean	(*unitCanReadFrom$0db80b916700aa7c)(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*unitCanWriteTo$e50298a7ad8b028b)(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_NaiveSideEffectTester$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_NaiveSideEffectTester$vmethods	soot_jimple_NaiveSideEffectTester;
};

// Vtype
struct _jc_soot_jimple_NaiveSideEffectTester$vtype {
	_jc_type			type;
	_jc_soot_jimple_NaiveSideEffectTester$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_NaiveSideEffectTester$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_NaiveSideEffectTester$refs {
    _jc_soot_jimple_NaiveSideEffectTester$sub_refs	soot_jimple_NaiveSideEffectTester;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_NaiveSideEffectTester$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs	soot_jimple_NaiveSideEffectTester;
};

// Object instance structure
struct _jc_soot_jimple_NaiveSideEffectTester$object {
	_jc_soot_jimple_NaiveSideEffectTester$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_NaiveSideEffectTester$vtype	*vtype;
	_jc_soot_jimple_NaiveSideEffectTester$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_NaiveSideEffectTester$vtype _jc_soot_jimple_NaiveSideEffectTester$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_NaiveSideEffectTester, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_NaiveSideEffectTester$class_object;

#endif	/* _JC_soot_jimple_NaiveSideEffectTester_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/NaiveSideEffectTester.h <==
// public class soot.jimple.NaiveSideEffectTester

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7b79e7dcca142ae9 soot_jimple_NaiveSideEffectTester

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_NaiveSideEffectTester_H_
#define _JC_soot_jimple_NaiveSideEffectTester_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_NaiveSideEffectTester$sub_refs	_jc_soot_jimple_NaiveSideEffectTester$sub_refs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs	_jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$refs	_jc_soot_jimple_NaiveSideEffectTester$refs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$nonrefs	_jc_soot_jimple_NaiveSideEffectTester$nonrefs;
typedef struct _jc_soot_jimple_NaiveSideEffectTester$object	_jc_soot_jimple_NaiveSideEffectTester$object;

typedef const struct _jc_soot_jimple_NaiveSideEffectTester$vmethods	_jc_soot_jimple_NaiveSideEffectTester$vmethods;
typedef const struct _jc_soot_jimple_NaiveSideEffectTester$vtable	_jc_soot_jimple_NaiveSideEffectTester$vtable;
typedef const struct _jc_soot_jimple_NaiveSideEffectTester$vtype	_jc_soot_jimple_NaiveSideEffectTester$vtype;

// Constructors
extern void _jc_soot_jimple_NaiveSideEffectTester$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_NaiveSideEffectTester$method$newMethod$b27d7d51d7418014(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_NaiveSideEffectTester$method$unitCanReadFrom$0db80b916700aa7c(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_NaiveSideEffectTester$method$unitCanWriteTo$e50298a7ad8b028b(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_NaiveSideEffectTester$method_info$newMethod$b27d7d51d7418014;
extern _jc_method _jc_soot_jimple_NaiveSideEffectTester$method_info$unitCanReadFrom$0db80b916700aa7c;
extern _jc_method _jc_soot_jimple_NaiveSideEffectTester$method_info$unitCanWriteTo$e50298a7ad8b028b;

// Virtual methods structure
struct _jc_soot_jimple_NaiveSideEffectTester$vmethods {
	void	(*newMethod$b27d7d51d7418014)(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	jboolean	(*unitCanReadFrom$0db80b916700aa7c)(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*unitCanWriteTo$e50298a7ad8b028b)(_jc_env *, struct _jc_soot_jimple_NaiveSideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_NaiveSideEffectTester$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_NaiveSideEffectTester$vmethods	soot_jimple_NaiveSideEffectTester;
};

// Vtype
struct _jc_soot_jimple_NaiveSideEffectTester$vtype {
	_jc_type			type;
	_jc_soot_jimple_NaiveSideEffectTester$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_NaiveSideEffectTester$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_NaiveSideEffectTester$refs {
    _jc_soot_jimple_NaiveSideEffectTester$sub_refs	soot_jimple_NaiveSideEffectTester;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_NaiveSideEffectTester$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_NaiveSideEffectTester$sub_nonrefs	soot_jimple_NaiveSideEffectTester;
};

// Object instance structure
struct _jc_soot_jimple_NaiveSideEffectTester$object {
	_jc_soot_jimple_NaiveSideEffectTester$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_NaiveSideEffectTester$vtype	*vtype;
	_jc_soot_jimple_NaiveSideEffectTester$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_NaiveSideEffectTester$vtype _jc_soot_jimple_NaiveSideEffectTester$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_NaiveSideEffectTester, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_NaiveSideEffectTester$class_object;

#endif	/* _JC_soot_jimple_NaiveSideEffectTester_H_ */
